﻿using Jypeli;
using System;

/// @author  Micke Saarnela
/// @version 11.10.2023
///
/// <summary>
/// Jyväskylän yliopiston Ohjelmointi 1 -kurssin harjoitustyö, syksy 2023.
/// </summary>

namespace Superpallo3000
{
    /// <summary>
    /// Pelialueen reunaolion luokka, yläreuna, vasen ja oikea sivureuna.
    /// Rajaa pelialueen niin, että pallo kimpoaa osuttuaan reunaan.
    /// Pallon törmäyksestä soitetaan ääniefekti.
    /// </summary>
    class Reuna : PhysicsObject
    {
        /// <summary>
        /// Pääohjelma kuuntelee tämän tapahtumankäsittelijän lähettämiä viestejä.
        /// </summary>
        /// <remarks>Viesti lähetetään kun pallo on osunut reunaan.</remarks>
        public event EventHandler<AaniefektienTyypit> SoitaAaniefekti;        
        
        /// <summary>
        /// Luokan konstruktori.
        /// </summary>
        /// <param name="x">Keskipiste X-akselilla.</param>
        /// <param name="y">Keskipiste Y-akselilla.</param>
        /// <param name="leveys">Reunan leveys pikseleinä.</param>
        /// <param name="korkeus">Reunan korkeus pikseleinä.</param>
        /// <param name="vari">Reunan väri.</param>       
        public Reuna(int x, int y, int leveys, int korkeus, Color vari) : base(leveys, korkeus)
        {
            // base(leveys, korkeus) -> kutsutaan PhysicsObject-luokan constructoria

            MakeStatic(); // staattinen olio
            Restitution = 1.0; // kimmoisuus, ei muuta pallon nopeutta jos arvo on 1
            KineticFriction = 0;
                       
            X = x;
            Y = y;
            Color = vari;             
        }


        /// <summary>
        /// Pallo törmäsi reunaan, lähetetään viesti, jossa pyydetään soittamaan tietty ääniefekti.
        /// </summary>
        public void PalloTormasi()
        {
           SoitaAaniefekti?.Invoke(this, AaniefektienTyypit.Reuna);                
        } 

    }
}
